summaryrefslogtreecommitdiffstats
path: root/src/include/usr/errl/errlentry.H
diff options
context:
space:
mode:
authorBrian Horton <brianh@linux.ibm.com>2013-10-25 14:52:43 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-11-14 17:10:27 -0600
commit931ed57963b8f63c67dc45144c2bb65b3f014a56 (patch)
treead8cb470618236b50a201cb1995ec66d9a2a2d9c /src/include/usr/errl/errlentry.H
parent7c353ef9c158531352888b47264ace19675b95f8 (diff)
downloadtalos-hostboot-931ed57963b8f63c67dc45144c2bb65b3f014a56.tar.gz
talos-hostboot-931ed57963b8f63c67dc45144c2bb65b3f014a56.zip
store error logs in PNOR
. store error logs in PNOR, truncating to 4K . set and clear ACKnowledge bit as appropriate . move PNOR and MBOX init code in errlmanager until after PNOR and MBOX services are actually up and running Change-Id: I57c5bacae8ffd283577164a0706c081a8ef5af30 RTC: 47517 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/6884 Tested-by: Jenkins Server Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/include/usr/errl/errlentry.H')
-rw-r--r--src/include/usr/errl/errlentry.H22
1 files changed, 18 insertions, 4 deletions
diff --git a/src/include/usr/errl/errlentry.H b/src/include/usr/errl/errlentry.H
index 6e67bf55c..d00c9c54a 100644
--- a/src/include/usr/errl/errlentry.H
+++ b/src/include/usr/errl/errlentry.H
@@ -604,18 +604,32 @@ private:
/**
+ * @brief sort compare function, to be used when flattening an
+ * error log
+ *
+ * @param[in] i_ud1 - first user-defined section to compare
+ * @param[in] i_ud2 - second user-defined section to compare
+ *
+ * @return true if i_ud1 should be first, false otherwise
+ */
+ static bool udSort(ErrlUD *i_ud1, ErrlUD *i_ud2);
+
+ /**
* @brief Flatten the data to caller's buffer. The resulting flat
* data will be in PEL (platform event log) format.
* The ErrlManager is the primary user of this call.
*
* @param[in,out] o_buffer Points to data block to be filled
- * @param[in] i_cbBuffer Count of bytes in buffer supplied
+ * @param[in] i_cbBuffer Count of bytes in buffer supplied
+ * @param[in] i_truncate true: truncate the data
+ * false: error if buffer too small
+ * NOTE: PH, UH and PS MUST fit
*
* @return Count of bytes copied to caller's
* buffer or else zero if it does not fit.
*/
- uint64_t flatten( void * o_buffer, const uint64_t i_cbBuffer );
-
+ uint64_t flatten( void * o_buffer, const uint64_t i_cbBuffer,
+ const bool i_truncate = false);
/**
* @brief Called by commit(), this fucntion creates a
OpenPOWER on IntegriCloud
@@ -604,18 +604,32 @@ private:
*
* @return Count of bytes copied to caller's
- * buffer or else zero if it does not fit.
+ * buffer or else zero if it does not fit and i_truncate==false.
*/